<?php

namespace Bixo\Payment\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Payment\Http\Resources\PaymentResource;
use Bixo\Payment\Http\Resources\PaymentsCollection;
use Bixo\Payment\Scopes\DetailPublicScope;
use Bixo\Payment\Models\Detail;

class DetailPublicController extends BaseController
{

    /**
     * Show detail's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Detail::pushScope(new RequestScope())
            ->pushScope(new DetailPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $details = new DetailsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('payment::detail.names'))
            ->view('payment::public.detail.index')
            ->data(compact('details', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show detail.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Detail::findBySlug($slug);
        $data = new DetailResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('payment::detail.name'))
            ->view('payment::public.detail.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
