<?php

namespace Bixo\Payment\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Payment\Actions\GatewayAction;
use Bixo\Payment\Http\Requests\GatewayActionRequest;
use Bixo\Payment\Http\Resources\GatewayResource;
use Bixo\Payment\Models\Gateway;

/**
 * Admin web controller class.
 */
class GatewayActionController extends BaseController
{

    /**
     * Action controller function for gateway.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(GatewayActionRequest $request, Gateway $gateway, $action)
    {
        try {
            $request = $request->all();
            $gateway = GatewayAction::run($action, $gateway, $request);

            $data = new GatewayResource($gateway);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('payment::gateway.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('payment/gateway/' . $gateway->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('payment/gateway/' . $gateway->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
