<?php

namespace Bixo\Payment\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Payment\Actions\GatewayExim;
use Bixo\Payment\Http\Requests\GatewayEximRequest;

/**
 * Admin web controller class.
 */
class GatewayEximController extends BaseController
{
    /**
     * Action controller function for gateway.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(GatewayEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = GatewayExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('payment:gateway.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('payment/gateway/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('payment/gateway/' . $exim))
                ->redirect();
        }
    }
}
