<?php

namespace Bixo\Payment\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Payment\Http\Resources\PaymentResource;
use Bixo\Payment\Http\Resources\PaymentsCollection;
use Bixo\Payment\Scopes\GatewayPublicScope;
use Bixo\Payment\Models\Gateway;

class GatewayPublicController extends BaseController
{

    /**
     * Show gateway's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Gateway::pushScope(new RequestScope())
            ->pushScope(new GatewayPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $gateways = new GatewaysCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('payment::gateway.names'))
            ->view('payment::public.gateway.index')
            ->data(compact('gateways', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show gateway.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Gateway::findBySlug($slug);
        $data = new GatewayResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('payment::gateway.name'))
            ->view('payment::public.gateway.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
