<?php

namespace Bixo\Payment\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Payment\Http\Resources\PaymentResource;
use Bixo\Payment\Http\Resources\PaymentsCollection;
use Bixo\Payment\Scopes\InvoicePublicScope;
use Bixo\Payment\Models\Invoice;

class InvoicePublicController extends BaseController
{

    /**
     * Show invoice's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Invoice::pushScope(new RequestScope())
            ->pushScope(new InvoicePublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $invoices = new InvoicesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('payment::invoice.names'))
            ->view('payment::public.invoice.index')
            ->data(compact('invoices', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show invoice.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Invoice::findBySlug($slug);
        $data = new InvoiceResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('payment::invoice.name'))
            ->view('payment::public.invoice.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
