<?php

namespace Bixo\Payment\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Payment\Actions\PaymentExim;
use Bixo\Payment\Http\Requests\PaymentEximRequest;

/**
 * Admin web controller class.
 */
class PaymentEximController extends BaseController
{
    /**
     * Action controller function for payment.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PaymentEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = PaymentExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('payment:payment.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('payment/payment/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('payment/payment/' . $exim))
                ->redirect();
        }
    }
}
