<?php

namespace Bixo\Payment\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Payment\Actions\RefundAction;
use Bixo\Payment\Http\Requests\RefundActionRequest;
use Bixo\Payment\Http\Resources\RefundResource;
use Bixo\Payment\Models\Refund;

/**
 * Admin web controller class.
 */
class RefundActionController extends BaseController
{

    /**
     * Action controller function for refund.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(RefundActionRequest $request, Refund $refund, $action)
    {
        try {
            $request = $request->all();
            $refund = RefundAction::run($action, $refund, $request);

            $data = new RefundResource($refund);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('payment::refund.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('payment/refund/' . $refund->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('payment/refund/' . $refund->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
