<?php

namespace Bixo\Payment\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Bixo\Payment\Http\Requests\RefundActionsRequest;
use Bixo\Payment\Actions\RefundActions;

/**
 * Admin web controller class.
 */
class RefundActionsController extends BaseController
{

    /**
     * Action controller function for refund.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(RefundActionsRequest $request, $action)
    {
        try {
            $refund = RefundActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('payment::refund.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('payment/refund/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('payment/refund/' . $action))
                ->redirect();
        }
    }
}
