<?php

namespace Bixo\Payment\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Payment\Events\DetailWorkflow as DetailWorkflowEvent;
use Bixo\Payment\Notifications\DetailWorkflow as DetailWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class DetailWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(DetailWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $detail is submitted.
     *
     * @param DetailWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(DetailWorkflowEvent $event)
    {
        $client = $event->detail->client;
        Notification::send($client, new DetailWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $detail is published.
     *
     * @param DetailWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(DetailWorkflowEvent $event)
    {
        $client = $event->detail->client;
        Notification::send($client, new DetailWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $detail is approved.
     *
     * @param DetailWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(DetailWorkflowEvent $event)
    {
        $client = $event->detail->client;
        Notification::send($client, new DetailWorkflowNotification($event));
    }

    /**
     * Handles the $detail workflow event as a listener.
     *
     * @param DetailWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(DetailWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
