<?php

namespace Bixo\Payment\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Payment\Events\GatewayAction as GatewayActionEvent;
use Bixo\Payment\Notifications\GatewayAction as GatewayActionNotification;
use Litepie\Actions\Concerns\AsAction;

class GatewayAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the GatewayActionEvent.
     *
     * @param   GatewayActionEvent  $event
     * @return mixed
     */
    public function handle(GatewayActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $gateway.
     *
     * @param   GatewayActionEvent  $event
     * @return void
     */
    public function create(GatewayActionEvent $event)
    {
        $client = $event->gateway->client;
        Notification::send($client, new GatewayActionNotification($event));
    }

    /**
     * Handle the GatewayActionEvent as a listener.
     *
     * @param   GatewayActionEvent  $event
     * @return mixed
     */
    public function asListener(GatewayActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   GatewayActionEvent  $event
     * @return bool
     */
    private function isAllowed(GatewayActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
