<?php

namespace Bixo\Payment\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Payment\Events\InvoiceAction as InvoiceActionEvent;
use Bixo\Payment\Notifications\InvoiceAction as InvoiceActionNotification;
use Litepie\Actions\Concerns\AsAction;

class InvoiceAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the InvoiceActionEvent.
     *
     * @param   InvoiceActionEvent  $event
     * @return mixed
     */
    public function handle(InvoiceActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $invoice.
     *
     * @param   InvoiceActionEvent  $event
     * @return void
     */
    public function create(InvoiceActionEvent $event)
    {
        $client = $event->invoice->client;
        Notification::send($client, new InvoiceActionNotification($event));
    }

    /**
     * Handle the InvoiceActionEvent as a listener.
     *
     * @param   InvoiceActionEvent  $event
     * @return mixed
     */
    public function asListener(InvoiceActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   InvoiceActionEvent  $event
     * @return bool
     */
    private function isAllowed(InvoiceActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
