<?php

namespace Bixo\Payment\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Payment\Events\InvoiceWorkflow as InvoiceWorkflowEvent;
use Bixo\Payment\Notifications\InvoiceWorkflow as InvoiceWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class InvoiceWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(InvoiceWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $invoice is submitted.
     *
     * @param InvoiceWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(InvoiceWorkflowEvent $event)
    {
        $client = $event->invoice->client;
        Notification::send($client, new InvoiceWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $invoice is published.
     *
     * @param InvoiceWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(InvoiceWorkflowEvent $event)
    {
        $client = $event->invoice->client;
        Notification::send($client, new InvoiceWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $invoice is approved.
     *
     * @param InvoiceWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(InvoiceWorkflowEvent $event)
    {
        $client = $event->invoice->client;
        Notification::send($client, new InvoiceWorkflowNotification($event));
    }

    /**
     * Handles the $invoice workflow event as a listener.
     *
     * @param InvoiceWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(InvoiceWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
