<?php

namespace Bixo\Payment\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Payment\Events\PaymentAction as PaymentActionEvent;
use Bixo\Payment\Notifications\PaymentAction as PaymentActionNotification;
use Litepie\Actions\Concerns\AsAction;

class PaymentAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the PaymentActionEvent.
     *
     * @param   PaymentActionEvent  $event
     * @return mixed
     */
    public function handle(PaymentActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $payment.
     *
     * @param   PaymentActionEvent  $event
     * @return void
     */
    public function create(PaymentActionEvent $event)
    {
        $client = $event->payment->client;
        Notification::send($client, new PaymentActionNotification($event));
    }

    /**
     * Handle the PaymentActionEvent as a listener.
     *
     * @param   PaymentActionEvent  $event
     * @return mixed
     */
    public function asListener(PaymentActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   PaymentActionEvent  $event
     * @return bool
     */
    private function isAllowed(PaymentActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
