<?php

namespace Bixo\Payment\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Payment\Events\RefundAction as RefundActionEvent;
use Bixo\Payment\Notifications\RefundAction as RefundActionNotification;
use Litepie\Actions\Concerns\AsAction;

class RefundAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the RefundActionEvent.
     *
     * @param   RefundActionEvent  $event
     * @return mixed
     */
    public function handle(RefundActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $refund.
     *
     * @param   RefundActionEvent  $event
     * @return void
     */
    public function create(RefundActionEvent $event)
    {
        $client = $event->refund->client;
        Notification::send($client, new RefundActionNotification($event));
    }

    /**
     * Handle the RefundActionEvent as a listener.
     *
     * @param   RefundActionEvent  $event
     * @return mixed
     */
    public function asListener(RefundActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   RefundActionEvent  $event
     * @return bool
     */
    private function isAllowed(RefundActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
