<?php
namespace Bixo\Payment\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Payment\Events\DetailAction as DetailActionEvent;
use Bixo\Payment\Models\Detail;

class DetailAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $detail;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param DetailActionEvent $detail
     */
    public function __construct(DetailActionEvent $detail)
    {
        $this->action = $event->action;
        $this->detail = $detail;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Detail Approved - ' . config('app.name'))
            ->view('payment::detail.email.action', ['data' => $this->detail]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
