<?php
namespace Bixo\Payment\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Payment\Events\GatewayAction as GatewayActionEvent;
use Bixo\Payment\Models\Gateway;

class GatewayAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $gateway;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param GatewayActionEvent $gateway
     */
    public function __construct(GatewayActionEvent $gateway)
    {
        $this->action = $event->action;
        $this->gateway = $gateway;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Gateway Approved - ' . config('app.name'))
            ->view('payment::gateway.email.action', ['data' => $this->gateway]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
