<?php
namespace Bixo\Payment\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Payment\Events\PaymentAction as PaymentActionEvent;
use Bixo\Payment\Models\Payment;

class PaymentAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $payment;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param PaymentActionEvent $payment
     */
    public function __construct(PaymentActionEvent $payment)
    {
        $this->action = $event->action;
        $this->payment = $payment;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Payment Approved - ' . config('app.name'))
            ->view('payment::payment.email.action', ['data' => $this->payment]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
