<?php
namespace Bixo\Payment\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Payment\Events\RefundAction as RefundActionEvent;
use Bixo\Payment\Models\Refund;

class RefundAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $refund;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param RefundActionEvent $refund
     */
    public function __construct(RefundActionEvent $refund)
    {
        $this->action = $event->action;
        $this->refund = $refund;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Refund Approved - ' . config('app.name'))
            ->view('payment::refund.email.action', ['data' => $this->refund]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
