<?php

namespace Bixo\Payment\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Payment\Models\Gateway;

class GatewayPolicy
{

    use GatewayAction;
    use GatewayExim;
    use GatewayReport;
    use GatewayWorkflow;

    /**
     * Determine if the given user can view the gateway.
     *
     * @param Authenticatable $user
     * @param Gateway $gateway
     *
     * @return bool
     */
    public function view(Authenticatable $user, Gateway $gateway)
    {
        if ($authUser->canDo('payment.gateway.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $gateway->is_owner;
    }

    /**
     * Determine if the given user can create a gateway.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('payment.gateway.create');
    }

    /**
     * Determine if the given user can update the given gateway.
     *
     * @param Authenticatable $user
     * @param Gateway $gateway
     *
     * @return bool
     */
    public function update(Authenticatable $user, Gateway $gateway)
    {
        if ($user->canDo('payment.gateway.edit') && $user->isAdmin()) {
            return true;
        }

        return $gateway->is_owner;
    }

    /**
     * Determine if the given user can delete the given gateway.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Gateway $gateway)
    {
        return $gateway->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
