<?php

namespace Bixo\Payment\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Payment\Models\Payment;

class PaymentPolicy
{

    use PaymentAction;
    use PaymentExim;
    use PaymentReport;
    use PaymentWorkflow;

    /**
     * Determine if the given user can view the payment.
     *
     * @param Authenticatable $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function view(Authenticatable $user, Payment $payment)
    {
        if ($authUser->canDo('payment.payment.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $payment->is_owner;
    }

    /**
     * Determine if the given user can create a payment.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('payment.payment.create');
    }

    /**
     * Determine if the given user can update the given payment.
     *
     * @param Authenticatable $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function update(Authenticatable $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.edit') && $user->isAdmin()) {
            return true;
        }

        return $payment->is_owner;
    }

    /**
     * Determine if the given user can delete the given payment.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Payment $payment)
    {
        return $payment->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
