<?php

namespace Bixo\Payment\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Payment\Models\Refund;

class RefundPolicy
{

    use RefundAction;
    use RefundExim;
    use RefundReport;
    use RefundWorkflow;

    /**
     * Determine if the given user can view the refund.
     *
     * @param Authenticatable $user
     * @param Refund $refund
     *
     * @return bool
     */
    public function view(Authenticatable $user, Refund $refund)
    {
        if ($authUser->canDo('payment.refund.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $refund->is_owner;
    }

    /**
     * Determine if the given user can create a refund.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('payment.refund.create');
    }

    /**
     * Determine if the given user can update the given refund.
     *
     * @param Authenticatable $user
     * @param Refund $refund
     *
     * @return bool
     */
    public function update(Authenticatable $user, Refund $refund)
    {
        if ($user->canDo('payment.refund.edit') && $user->isAdmin()) {
            return true;
        }

        return $refund->is_owner;
    }

    /**
     * Determine if the given user can delete the given refund.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Refund $refund)
    {
        return $refund->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
