<?php

namespace Bixo\Payment\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Bixo\Payment\Models\Detail;
use Bixo\Payment\Models\Refund;
use Bixo\Payment\Models\Invoice;
use Bixo\Payment\Models\Gateway;
use Bixo\Payment\Models\Payment;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Payment\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/payment/detail/*')) {
            Route::bind('detail', function ($detail) {
                return Detail::findorNew($detail);
            });
        }
        if (Request::is('*/payment/refund/*')) {
            Route::bind('refund', function ($refund) {
                return Refund::findorNew($refund);
            });
        }
        if (Request::is('*/payment/invoice/*')) {
            Route::bind('invoice', function ($invoice) {
                return Invoice::findorNew($invoice);
            });
        }
        if (Request::is('*/payment/gateway/*')) {
            Route::bind('gateway', function ($gateway) {
                return Gateway::findorNew($gateway);
            });
        }
        if (Request::is('*/payment/payment/*')) {
            Route::bind('payment', function ($payment) {
                return Payment::findorNew($payment);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
